# -*- coding: utf-8 -*-
import requests
import json

# WioNodeの基底クラス
class WioNode:
    token = ''

    # コンストラクタ
    def __init__(self, my_token):
        self.token = my_token


# WioNode+温湿度センサ(DHT11)のクラス
class WioDHT11(WioNode):
    # 温度（摂氏）の取得
    def getTempreture(self):
        url = "https://us.wio.seeed.io/v1/node/GroveTempHumD0/temperature?access_token=" + self.token
        headers = {"content-type": "application/json"}
        r = requests.get(url, headers=headers)
        data = r.json()
        degree = data["celsius_degree"]
        return degree

    # 湿度の取得
    def getHumidity(self):
        url = "https://us.wio.seeed.io/v1/node/GroveTempHumD0/humidity?access_token=" + self.token
        headers = {"content-type": "application/json"}
        r = requests.get(url, headers=headers)
        data = r.json()
        humidity = data["humidity"]
        return humidity

    # 不快指数の算出
    @staticmethod
    def getDiscomfortIndex(temp, hum):
        discomfort_index = 0.81 * temp + 0.01 * hum * (0.99 * temp - 14.3) + 46.3
        return discomfort_index

# WioNode+光センサのクラス
class WioLightSensor(WioNode):
    # 明るさの取得
    def getLux(self):
        url = "https://us.wio.seeed.io/v1/node/GroveLuminanceA0/luminance?access_token=" + self.token
        headers = {"content-type": "application/json"}
        r = requests.get(url, headers=headers)
        data = r.json()
        lux = data["lux"]
        return lux

print('-------------------------------------')

wio = WioDHT11('------ トークンを入力する ------')

t = wio.getTempreture()
print(str(t) + '℃')
h = wio.getHumidity()
print(str(h) + '%')
print(str(wio.getDiscomfortIndex(t, h)))
print('-------------------------------------')


wio2 = WioLightSensor('------ トークンを入力する ------')
l = wio2.getLux()
print(str(l))
print('-------------------------------------')
